@@ -1,3 +1,4 @@
+import sys
 import click
 
 from taiconvert.commands import convert, extract
@@ -13,7 +14,6 @@ def cli():
 cli.add_command(convert, name="convert")
 cli.add_command(extract, name="extract")
 
-
-def first_command(example, option):
-    "Command description goes here"
-    click.echo("Here is some output")
+# Run cli function if script is frozen by pyinstaller
+if getattr(sys, "frozen", False):
+    cli(sys.argv[1:])
